#include "ti86asm.inc"


.org _asm_exec_ram

mem         = $8800


lenght      = mem + 5   ;2
direction2  = mem + 7   ;1
key         = mem + 8   ;1
seed        = mem + 9   ;2
food        = mem + 11  ;2  
will_grow   = mem + 13  ;1
end_now     = mem + 14  ;1
chance2     = mem + 15  ;1
direction   = mem + 16  ;1  
level       = mem + 17  ;1
speed       = mem + 18  ;1
points      = mem + 19  ;2
last_piece  = mem + 21  ;2
snake       = mem + 23  ;the rest


    call _flushallmenus


;NOTE:If you use this routine, remember to define seed as a 2-byte variable, and randnum as
;a single-byte variable, unless you want to change their names.  Before using it for the first time,
;make sure to call RSeed.
;Here c is used instead of randnum

RSeed:              ;gedownate a new starting number
    call _random        ;0<=op1<1
    call _inco1exp      ;op1*10
    call _inco1exp      ;"      these 4 lines =op1*10,000
    call _inco1exp      ;"
    call _inco1exp      ;"
    call _INTGR         ;make op1 an integer
    call _convop1       ;conv op1 to de,a
    ld (seed),de        ;we want 2 bytes of random stuff
    ld b,3          ;set loop counter at 3
ShiftSeedLoop:
    ld hl,(seed)        ;this section shifts seed as a whole.
    sla h
    bit 7,l         ;test bit 7 of lower byte
    jp z,noinc
    inc h
noinc:
    sla l
    ld (seed),hl        ;end
    djnz ShiftSeedLoop  



    call _clrScrn
    ld hl,0
    ld (_penCol),hl
    ld hl,level_t
    call _vputs
    ld bc,7*256
    ld (_penCol),bc
    call _vputs
    ld bc,21*256
    ld (_penCol),bc
    call _vputs
    
;inputs the level
level_keyloop:
    call _getky
    or a
    jr z,level_keyloop
    cp K_EXIT
    ret z
    
    
    ld hl,number_keys
    ld bc,10
    cpir
    jp po,level_keyloop
    ld a,c
    ld d,0
    ld e,a
    ld (level),a


;calculates the speed according to the chosen level
    ld hl,speeds-1      ;a list containing speeds for different levels, -1 so level 1 will give the first value
    add hl,de           ;de also contains the inputted value, adds the values to get the right entry of the list
    ld a,(hl)
    ld (speed),a        ;stores

    call _runindicoff
    call _clrLCD

;saves some initial values, using hl is 2 bytes shorter and 2 cycles slower then just ld:ing
    xor a               ;aka ld a,0
    ld hl,will_grow
    ld (hl),a           ;ld (will_grow),a
    inc hl
    ld (hl),a           ;ld (end_now),a
    inc hl
    ld (hl),a           ;ld (chance2),a

    ld a,3
    inc hl
    ld (hl),a           ;ld (direction),a
    
    ld hl,18
    ld (lenght),hl

    ld hl,0
    ld (points),hl

;draws the left border
    ld hl,$fc20     ;the beginning of the third row of the screen
    ld a,%10000000
    ld b,46         ;number of rows to draw
    ld de,16        ;1 row = 16 bytes in the memory
left_loop:
    ld (hl),a       
    add hl,de       
    djnz left_loop

;draws the right border
    ld hl,$fc2a
    ld a,%00100000
    ld b,46
    ld de,16
right_loop:
    ld (hl),a
    add hl,de
    djnz right_loop

;draws the top border

    ld hl,$fc10         ;second row
    ld b,10             ;now there is 9*8 pixels to color
    ld a,%11111111      ;all the pixels
up_loop:
    ld (hl),a   

    inc hl  
    djnz up_loop

    ld a,%11100000      ;the last byte
    ld (hl),a           ;hl already inc:ed


;draws the bottom border
    ld hl,$fef0         ;row 47 (i think)
    ld b,10
    ld a,%11111111
down_loop:
    ld (hl),a
    inc hl
    djnz down_loop

    ld a,%11100000
    ld (hl),a   



;draws then snake and sets the initial snake list
    ld b,9          ;9 pieces
    ld de,$10B      ;d=x=0,e=y=11
    ld hl,snake
start_snake_loop:
    inc d           ;next x value
    push bc         ;saves, destroyed by the sprite routine
    push de         ;ditto
;sets snake list
    ld (hl),d
    inc hl
    ld (hl),e
    inc hl
    push hl
    ld b,d          ;d is instead of b due to the loop
    ld c,e
    call snake_sprite   ;draws the sprite
    pop hl
    pop de          ;restores
    pop bc          ;ditto
    
    djnz start_snake_loop   ;next piece




;puts the first food piece
    ld hl,food      ;where to save
    ld bc,$b06      ;b=x=11,c=y=6

    ld (hl),b
    inc hl
    ld (hl),c

    ld hl,FoodSprite
    call sprite     ;displays it
    
    call pause      ;the game will soon begin...

main_loop:

;checks if the game will end (set by "call will_end_now")
    ld a,(end_now)
    cp 1
    jp z,exit               ;exits the game showing the score

;checks if the snake shall grpw
    ld a,(will_grow)
    cp 1
    jp z,increase           ;grows it

;updates the snake list, moves every byte two bytes backwards in the list
    ld hl,(lenght)          ;the lenght of the snake to bc (the number of bytes for ldir to copy)
    ld b,h
    ld c,l
    ld hl,snake             
    ld de,snake-2           
    ldir                    

;hl=snake+lenght-4 (points to the bytes that were first the last turn)
    ld de,snake-4           
    ld hl,(lenght)
    add hl,de

;here the program returns after growing the snake
back_from_increase:
;loads the coordinats of the first part of the snake to bc
    ld b,(hl)
    inc hl
    ld c,(hl)
    call change_direction   ;inc or dec b or c depending on the direction of the snake

;checks if the skake hitted anything
    call hit?

;if it did chance2 is set to 1, then the player will get another chance to save the snake
    ld a,(chance2)
    cp 1
    jp z,chance1

back_from_chance1:
;removes the last piece of the snake from the game
    push bc             ;saves because the coordinats of the first piece are already stored in bc
    ld hl,last_piece    ;pointer to the last piece
;stores the coordinats to bc
    ld b,(hl)
    inc hl
    ld c,(hl)   
    ld hl,EmptySprite   ;an empty sprite
    call sprite         ;displays it
    pop bc              ;recovers

;hl points to the coordinats of the first piece
    ld de,snake-2
    ld hl,(lenght)
    add hl,de

;saves the coordinates
    ld (hl),b
    inc hl
    ld (hl),c
    call snake_sprite   ;displays the new piece of the snake


;puts a new piece of food on the screen if the last one was eaten
    ld a,(will_grow)    
    cp 1
    call z,new_food


    call pause ;slows the game down and registers keypresses
    jp main_loop


;giving the player a 2:nd chance
chance1:
    ld a,5
    ld (direction2),a
    call pause          ;pauses

;hl points to the 2:nd piece of the snake
;(the first one has already collided into something but isn't yet displayed)
    ld de,snake-4
    ld hl,(lenght)
    add hl,de

;loads the coordinats into bc
    ld b,(hl)
    inc hl
    ld c,(hl)
;moves the first piece antoher time
    call change_direction

;checks if it hits something again (the direction may be changed at call pause
    call hit?

;exits if it stil hitts something
    ld a,(chance2)
    cp 1
    jp nz,exit
;else it resets the chance2
    ld a,0
    ld (chance2),a
;and returns to
    jp back_from_chance1


;slows down the game
pause:
;checks how many times the loop will be run
    ld a,(speed)
    ld b,a
pause_loop:
;pauses
    halt
    ld a, %11111110 ;the arrow keys
    di              ;disable the down-left bug
    out (1), a
    in a, (1)
    ei

;stores the directions to direction
    ld hl,direction 
    bit 1,a
    jp z,left
    bit 2,a
    jp z,right
    bit 3,a
    jp z,up
    bit 0,a
    jp z,down

;more and exit
    ld a,%10111111
    di
    out (1),a
    nop
    nop
    in a,(1)
    ei
    bit 6,a         ;exit
    call z,will_end_now
    bit 7,a         ;more
    call z,_getkey  ;pauses

;returns to here after the arrow checking
after_button:
    djnz pause_loop
    ret


;makes the game end the next turn
will_end_now:
    ld a,1
    ld (end_now),a
    ld a,255        ;to awoid thinking mode was pressed when returning
    ret


;gives the player another chance
will_die:
    ld hl,chance2
    inc (hl)
    ret


;Puts a new piece of foosd into the game
new_food:
;d=random integrer between 1 and 20
x_loop:
    call Random     ;c=random number
    ld a,c
    and %00011111   ;lesser than 32
    cp 20           ;lesser than 21
    jp nc,x_loop
    inc a

;saves the value
    ld (food),a
    ld d,a
    push de     ;destroyed by random

;a=random integrer between 1 an 11
y_loop:
    call Random
    ld a,c
    and %00001111   ;lesser than 16
    cp 11
    jp nc,y_loop
    inc a

;loads the coordinats yo bc
    pop de
    ld b,d
    ld c,a
    ld (food+1),a


;restarts if there is a snake at the coordinates
    ld de,0         ;counter
food_hit_snake_loop:
;hl=snake+the counter-2
    ld hl,snake-2
    add hl,de
;checks the x coordinat
    ld a,(hl)
    cp b
;no need to check the y if the x wasn't
    jp nz,food_check_out
;next byte
    inc hl
    ld a,(hl)
    cp c
    jp z,x_loop         ;restarts if needed
food_check_out:
;increases the conter
    inc de
    inc de
;lh =lenght - 4 (exits if the counter (de)=length-4 (all the snake)
    ld hl,(lenght)
    inc hl
    inc hl
    inc hl
    inc hl
;reset carry for the sbc
    cp a
    sbc hl,de       ;aka cp hl,de

    jp nz,food_hit_snake_loop

    ld hl,FoodSprite        ;the sprite containing the food
    call sprite
    ret

;moves the first piece of the snake in the right direction
change_direction:
;direction2=direction (direction2 is used to prevent turning left when going right, up when going down...)
    ld a,(direction)
    ld (direction2),a
;just jumps to the right place where b or c is changed
    cp 1
    jp z,f_left
    cp 2
    jp z,f_down
    cp 3
    jp z,f_right
    cp 4
    jp z,f_up
    ret
f_left:
    dec b
    ret
f_down:
    inc c
    ret
f_right:
    inc b
    ret
f_up:
    dec c
    ret

;Is the snake hitting a piece of food or itself or a wall?
hit?
;Checking for food
    ld hl,food          ;where
    ld a,(hl)
    cp b                ;compared with x
    jp nz,continue_checking_hit     ;didnt hit, continue
;did hit checks with y
    inc hl
    ld a,(hl)
    cp c
    jp nz,continue_checking_hit
    ld a,1
    ld (will_grow),a        ;makes the snake grow
    
continue_checking_hit:
;checking walls
    ld a,0
    cp b
    call nc,will_die
    cp c
    call nc,will_die
    ld a,20
    cp b
    call c,will_die
    ld a,11
    cp c
    call c,will_die


;checks the snake

    ld de,0         ;counter
hit_loop:
    ld hl,snake     ;last piece
    add hl,de       ;+ the number of timse looped
    ld a,(hl)
    cp b            ;comp with b
    jp nz,hit_out   ;if didnt hit
;if x gave a hit checks for y
    inc hl
    ld a,(hl)
    cp c
    call z,will_die ;goodbye :-(

hit_out:
    inc de          ;increases counter
    inc de
    ld hl,(lenght)
    dec hl          ;hl=lenght -2   
    dec hl
;aka cp hl,de
    cp a                ;reset carry
    sbc hl,de

    jp nz,hit_loop  ;contunes if it wasn't the last byte
    ret


;exits (doh)
exit:
    call _clrScrn
    call _homeup
    ld hl,exit_t1   ;"Game Over!"
    call _puts
    push hl         ;the text countinues at hl
    call _newline
;diplays the points
    ld hl,(points)  
;displays 16 bit number
    call _setXXXXop2    ;hl to floating point in op2
    call _op2toop1
    ld a,5              ;max number of digits               
    call _formReal      ;makes a string in op3 of floating point number in op1
    ld hl,_OP3
    call _puts          ;displays it

    pop hl          ;where the text countinues
    call _puts      ;"points!
    call _newline   
    jp _getkey
;    ret
        

exit_t1:
    .text "Game Over!"
exit_t2:
    .text " points"


increase:
;resets so it wont grow all the time
    ld a,0
    ld (will_grow),a

;lenght=lenght+2
    ld hl,(lenght)
    inc hl
    inc hl
    ld (lenght),hl

;points=points+level
    ld hl,(points)
    ld a,(level)
    ld d,0
    ld e,a
    add hl,de
    ld (points),hl  

;hl=snake+lenght-4 returns with the correct value
    ld hl,(lenght)      
    ld de,snake-4
    add hl,de
    jp back_from_increase



;sets the direction according to the key presssed
;hl is set to direction
left:
    ld a,(direction2)
    cp 3
    jp z,after_button       ;cant turn left when going right
    ld (hl),1
    jp after_button
down:
    ld a,(direction2)
    cp 4
    jp z,after_button
    ld (hl),2
    jp after_button
right:
    ld a,(direction2)
    cp 1
    jp z,after_button
    ld (hl),3
    jp after_button
up:
    ld a,(direction2)
    cp 2
    jp z,after_button
    ld (hl),4
    jp after_button

;uses different sprites for the snake depending on the direction
snake_sprite:
    ld a,(direction)
    cp 1
    jp z,sprite_left
    cp 2
    jp z,sprite_down
    cp 3
    jp z,sprite_right
    cp 4
;   jp z,sprite_up

    ld hl,SnakeUSprite
    jp sprite
sprite_right:
    ld hl,SnakeASprite
    jp sprite
sprite_down:
    ld hl,SnakeDSprite
    jp sprite
sprite_left:
    ld hl,SnakeLSprite



;some calculating before putting the sprite x=(x-1)*4+1=x*4-3, y=y*4-2
sprite:
    dec b
    ld a,b
    add a,a
    add a,a
    inc a
    ld b,a

    ld a,c
    add a,a
    add a,a
    dec a
    dec a
    ld c,a
    
;=========================================================================
; Sprite routines by David Phillips <david@acz.org>    http://www.acz.org/
;=========================================================================
; All sprites are 8x8 masked sprites
;
;   PutSprite      -- black/white                 (sprite, mask)
;   PutSpriteClip  -- black/white with clipping   (sprite, snake)
;   GraySprite     -- grayscale                   (dark, light, mask)
;   GraySpriteClip -- grayscale with clipping     (dark, light, mask)
;
; in:   hl = pointer to sprite, bc = x,y location
; out:  af, bc, de, hl, ix = trash
; size: 250 bytes
;=========================================================================

VideoDraw = $fc00                   ; [1024] virtual screen or video ram

;GrayDraw1 = GrayMem1               ; [1024] dark grayscale plane
;GrayDraw2 = GrayMem2               ; [1024] light grayscale plane
;=========================================================================

; in: hl = 8x8 masked sprite, bc = x,y location

PutSpriteClip:
 ex de,hl                           ; save pointer in de
 ld hl,PutSpriteE                   ; need to call putsprite
 ld (ClipSpriteE),hl                ; modify call address
 jp ClipSprite                      ; jump to clipsprite

; in: de = sprite pointer, bc = x,y location
ClipSprite:
 ld a,b                             ; get x coord
 cp 249                             ; hanging off left edge?
 jp nc,ClipSpriteL                  ; then clip left edge
 cp 128                             ; completely off right edge?
 ret nc                             ; then don't draw it
 jp ClipSpriteR                     ; clip right edge
ClipSpriteL:
 res 7,b                            ; draw on right edge
 dec c                              ; move up a row (left clipping)
 bit 7,c                            ; are we on the top edge?
 jp z,ClipSpriteA                   ; if not, skip top fix
 ld hl,_@RenderSpriteCV             ; point to rows to draw
 inc (hl)                           ; increase it (decreased later)
 dec de                             ; decrease sprite pointer
 ld hl,-16                          ; need to draw up a row
 ld (_@ClipSpriteX),hl              ; modify top row fix value
ClipSpriteA:
 ld hl,$0218                        ; change instruction to <jp 2>
 ld (_@RenderSpriteCL),hl           ; modify to skip drawing left byte
 jp ClipSpriteH                     ; done clipping horizontal
ClipSpriteR:
 cp 120                             ; hanging off right edge?
 jp c,ClipSpriteH                   ; if not, don't clip
 ld hl,$0218                        ; change instruction to <jp 2>
 ld (_@RenderSpriteCR),hl           ; modify to skip drawing right byte
ClipSpriteH:
 ld a,c                             ; get y coord
 cp 249                             ; hanging off top?
 jp nc,ClipSpriteT                  ; then clip the top
 cp 64                              ; completely off the bottom?
 jp nc,ClipSpriteF                  ; then don't draw, but fix everything
 jp ClipSpriteB                     ; clip the bottom
ClipSpriteT:
 xor a                              ; clear for subtract
 ld h,a                             ; clear high byte
 sub c                              ; calc bytes above screen
 ld c,h                             ; set y coord to 0
 ld l,a                             ; set low byte to bytes above screen
 add hl,de                          ; advance sprite pointer
 ex de,hl                           ; swap back into de
 jp ClipSpriteV                     ; finish vertical clipping
ClipSpriteB:
 sub 56                             ; calc bytes below screen
 jp c,ClipSpriteD                   ; don't clip if not below screen
 inc a                              ; increase bytes below screen
ClipSpriteV:
 neg                                ; negate so it can be subtracted
_@ClipSpriteZ =$+1
 ld hl,_@RenderSpriteCV             ; point to rows to draw
 add a,(hl)                         ; add (subtract) from current value
 ld (hl),a                          ; save new value
ClipSpriteD:
 push de                            ; push sprite pointer
 pop ix                             ; pop sprite pointer in ix
 call FindAddress                   ; calc address and offset of sprite
_@ClipSpriteX =$+1
 ld de,0                            ; load address fix for top row
 add hl,de                          ; add the fix value
ClipSpriteE =$+1
 call $ffff                         ; call the correct sprite routine
ClipSpriteF:
 ld a,8                             ; normally 8 rows are drawn
 ld (_@RenderSpriteCV),a            ; set rows to draw back
 ld hl,$a678                        ; normal opcode is <ld a,b \ and (hl)>

 ld (_@RenderSpriteCL),hl           ; set instructions back
 inc l                              ; change <ld a,b> to <ld a,c>
 ld (_@RenderSpriteCR),hl           ; set instructions back
 ld hl,0                            ; normally top row fix is 0
 ld (_@ClipSpriteX),hl              ; set rox fix back

 ret                                ; return from clipping

; in: hl = 8x8 masked sprite, bc = x,y location
PutSprite:
 push hl                            ; push sprite pointer
 pop ix                             ; pop in ix
 call FindAddress                   ; calc address and offset
PutSpriteE:
 ld de,VideoDraw                    ; draw sprite to video memory
 add hl,de                          ; add offset to buffer start
 jp RenderSprite                    ; actually draw the sprite


; in: hl = address in buffer, c = offset, ix = sprite
RenderSprite:
_@RenderSpriteCV =$+1
 ld b,8                             ; set row counter to 8 bytes
RenderSpriteL:
 push bc                            ; save row counter and sprite offset
 ld a,(ix+8)                        ; load mask for this row
_@RenderSpriteM =$-1
 cpl                                ; invert the mask
 ld b,a                             ; save inverted mask
 ld d,(ix)                          ; load sprite byte for this row
 inc ix                             ; advance sprite pointer
 ld a,c                             ; set shift counter to sprite offset
 ld c,$ff                           ; set all bits of right mask byte
 ld e,0                             ; clear right byte of sprite
 or a                               ; is the sprite aligned?
 jp z,RenderSpriteD                 ; then skip shifting it
RenderSpriteS:
 srl d                              ; shift left sprite byte
 rr e                               ; into the right sprite byte
 scf                                ; set carry
 rr b                               ; shift left mask byte
 rr c                               ; into the right mask byte
 dec a                              ; decrease shift counter
 jp nz,RenderSpriteS                ; loop until counter is 0
RenderSpriteD:
_@RenderSpriteCL =$
 ld a,b                             ; load the left sprite byte
 and (hl)                           ; and it with the screen
 or d                               ; or it with the mask
 ld (hl),a                          ; set screen memory to left byte
 inc hl                             ; increase screen pointer
_@RenderSpriteCR =$
 ld a,c                             ; load the right sprite byte
 and (hl)                           ; and it with the screen
 or e                               ; or it with the mask
 ld (hl),a                          ; set screen memory to left byte
 ld de,15                           ; next row is 15 bytes ahead
 add hl,de                          ; move screen pointer to next row
 pop bc                             ; restore loop counter and shift mask
 djnz RenderSpriteL                 ; loop for all bytes in sprite
 ret                                ; done drawing the sprite

; in: bc = x,y location
; out: hl = offset of byte, c = offset in video byte
FindAddress:
 ld a,c                             ; get the y coord
 add a,a                            ; multiply by 2
 add a,a                            ; again by 4
 ld l,a                             ; save as low byte
 ld h,0                             ; clear high byte
 add hl,hl                          ; multiply by 8
 add hl,hl                          ; and again by 16
 ld a,b                             ; now get the x coord
 and %11111000                      ; clear lower 3 bits
 rra                                ; divide by 2
 rra                                ; this time by 4
 rra                                ; and finally by 8
 or l                               ; combine with low byte
 ld l,a                             ; save it
 ld a,b                             ; get x coord again
 and %00000111                      ; clear all but last 3 bits
 ld c,a                             ; save sprite offset in c
 ret                                ; return to caller



Random:
;Random Number Gedownator by Steven Hunt.  For details
;on how this routine works, see random.txt
;Please give me credit if you use it.
    ld hl,(seed)    ;this section shifts seed as a whole.
    sla h
    bit 7,l     ;test if shifting LB would overflow
    jp z,noinc1 ;if not, don't inc UB
    inc h
noinc1:
    sla l
    ld (seed),hl ;end

;   ld a,h  ;higher byte->a
;   ld (randnum),a

    ld c,h          ;c wont be used before the random number is used

testbit:            ;prepare new seed number (xor bit 14&15, store in bit 0)
    ld a,h          ;restore higher byte of seed
    and %01000000   ;maks all but bit 7 (15 of seed#)
    ld b,a          ;save result
    ld a,h
    sla a           ;shift higher byte left
    and %01000000   ;mask all but bit 7 (14 of seed# after shift)
    xor b           ;see if bits 15&14 are =
    jp z,resbit     ;test result of xor
    ld hl,seed
    set 0,(hl)      ;they were different, so set bit 0 of seed
    ret
resbit:             ;they were the same, so reset bit 0 of seed
    ld hl,seed
    res 0,(hl)
    ret  
    
number_keys:
    .db K_9,K_8,K_7,K_6,K_5,K_4,K_3,K_2,K_1



EmptySprite:
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %11111000
    .db %11111000
    .db %11111000
    .db %11111000
    .db %11111000
    .db %00000000
    .db %00000000
    .db %00000000

FoodSprite:
    .db %00000000
    .db %00100000
    .db %01010000
    .db %00100000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00100000
    .db %01010000
    .db %00100000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000

SnakeUSprite:
    .db %00000000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %00000000
    .db %00000000
    .db %00000000


SnakeLSprite:
    .db %00000000
    .db %01111000
    .db %01111000
    .db %01111000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %01111000
    .db %01111000
    .db %01111000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000

SnakeASprite:
    .db %00000000
    .db %11110000
    .db %11110000
    .db %11110000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %11110000
    .db %11110000
    .db %11110000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000

SnakeDSprite:
    .db %01110000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %01110000
    .db %00000000
    .db %00000000
    .db %00000000
    .db %00000000

level_t:
    .text "Snake 1.0 by Leif Astrand"
    .text "Email: leif.astrand@multi.fi"
    .text "Choose level (1-9):"

;how many times to do the pause loop depending on the level chosen
speeds:
    .db     118,87,70,52,50,40,31,24,18



.end
